@@ -11,7 +11,7 @@ require Exporter;
 # Do not simply export all your public functions/methods/constants.
 @EXPORT = qw( );
 
-$VERSION = '1.02';
+$VERSION = '1.10';
 
 use Carp;
 
@@ -98,6 +98,175 @@ sub initialize {
  #          number per sheet, left-offset, top-offset, width, height,
  #			x_gap, y_gap ]
  #			distances measured in points
+ # Aug 2004 updated using data from http://www.worldlabel.com
+	%{$self->{AVERY}} = (
+			'5096' => ['Letter',[qw/5096/], 'diskette', 9,
+					9, 36, 198, 198, 0, 18,
+			],
+			'5160' => ['Letter',[qw/5160 8250 8560 8660/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5161' => ['Letter',[qw/5161/], 'address', 20,
+					11.2464, 36, 288, 72, 11.2464, 0,
+			],
+			'5162' => ['Letter',[qw/5162 8252 8662/], 'address', 14,
+					11.2536, 63, 285.7536, 101.2536, 13.5, 0,
+			],
+			'5163' => ['Letter',[qw/5163 8253 8663/], 'special', 10,
+					13.5, 36, 288, 144, 9, 0,
+			],
+			'5164' => ['Letter',[qw/5164 8254/], 'shipping', 6,
+					10.656, 36, 288, 239.76, 14.6232, 0,
+			],
+			'5165' => ['Letter',[qw/5165 8255 8665/], 'full sheet', 1,
+					0, 0, 612, 792, 0, 0,
+			],
+			'5167' => ['Letter',[qw/5167 8257 8667/], 'return address', 80,
+					21.3768, 36, 126, 36, 21.7512, 0,
+			],
+			'5190' => ['Letter',[qw/5190/], 'diskette', 15,
+					13.5, 18, 192.024, 144, 4.5, 12.0744,
+			],
+			'5193' => ['Letter',[qw/5193/], 'special', 24,
+					29.2536, 38.2536, 117, 117, 28.1232, 2.7,
+			],
+			'5194' => ['Letter',[qw/5194/], 'special', 12,
+					29.2536, 39.3696, 176.6232, 176.6232, 18, 2.2536,
+			],
+			'5195' => ['Letter',[qw/5195/], 'special', 6,
+					46.1232, 34.8768, 238.5, 238.5, 42.7536, 3.3768,
+			],
+			'5196' => ['Letter',[qw/5196/], 'diskette', 9,
+					9, 36, 198, 198, 0, 18,
+			],
+			'5197' => ['Letter',[qw/5197/], 'special', 12,
+					11.8152, 72, 288, 108, 12.3768, 0,
+			],
+			'5198' => ['Letter',[qw/5198/], 'audio cassette', 12,
+					36, 38.2464, 252, 119.2464, 36, 0,
+			],
+			'5199-F' => ['Letter',[qw/5199-F/], 'VHS Face', 10,
+					76.5, 65.2464, 220.5, 132.3, 18, 0,
+			],
+			'5199-S' => ['Letter',[qw/5199-S/], 'VHS spine', 15,
+					95.6232, 33.7536, 420.7536, 48.2976, 0, 0,
+			],
+			'5260' => ['Letter',[qw/5260/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5261' => ['Letter',[qw/5261/], 'address', 20,
+					11.2464, 36, 288, 72, 11.2464, 0,
+			],
+			'5262' => ['Letter',[qw/5262/], 'address', 14,
+					11.2536, 63, 285.7536, 101.2536, 13.5, 0,
+			],
+			'5263' => ['Letter',[qw/5263/], 'shipping', 10,
+					13.5, 36, 288, 144, 9, 0,
+			],
+			'5264' => ['Letter',[qw/5264/], 'shipping', 6,
+					10.656, 36, 288, 239.76, 14.6232, 0,
+			],
+			'5265' => ['Letter',[qw/5265/], 'full sheet', 1,
+					0, 0, 612, 792, 0, 0,
+			],
+	         '5266' => ['Letter', [qw/8066 8166 8366/], 'file folder', 30,
+			            undef, undef, undef, undef, undef, undef,
+			 ],
+			'5267' => ['Letter',[qw/5267/], 'return address', 80,
+					21.3768, 36, 126, 36, 21.7512, 0,
+			],
+			'5293' => ['Letter',[qw/5293/], 'special', 24,
+					29.2536, 38.2536, 117, 117, 28.1232, 2.7,
+			],
+			'5294' => ['Letter',[qw/5294/], 'special', 12,
+					29.2536, 39.3696, 176.6232, 176.6232, 18, 2.2536,
+			],
+			'5295' => ['Letter',[qw/5295/], 'special', 6,
+					46.1232, 34.8768, 238.5, 238.5, 42.7536, 3.3768,
+			],
+	         '5395' => ['Letter', [qw/8395/], 'name badge', 8,
+			            undef, undef, undef, undef, undef, undef,
+			 ],
+			'5663' => ['Letter',[qw/5663/], 'address', 10,
+					0, 36, 306, 144, 0, 0,
+			],
+			'5667' => ['Letter',[qw/5667/], 'return address', 80,
+					21.3768, 36, 126, 36, 21.7512, 0,
+			],
+			'5824' => ['Letter',[qw/5824/], 'CD-Rom', 2,
+					144, 36, 324, 324, 0, 72,
+			],
+			'5896' => ['Letter',[qw/5896/], 'diskette', 9,
+					9, 36, 198, 198, 0, 18,
+			],
+			'5960' => ['Letter',[qw/5960/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5961' => ['Letter',[qw/5961/], 'address', 20,
+					11.2464, 36, 288, 72, 11.2464, 0,
+			],
+			'5962' => ['Letter',[qw/5962/], 'address', 14,
+					11.2536, 63, 285.7536, 101.2536, 13.5, 0,
+			],
+			'5963' => ['Letter',[qw/5963/], 'special', 10,
+					13.5, 36, 288, 144, 9, 0,
+			],
+			'5970' => ['Letter',[qw/5970/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5971' => ['Letter',[qw/5971/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5972' => ['Letter',[qw/5972/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5979' => ['Letter',[qw/5979/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'5980' => ['Letter',[qw/5980/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+	         '6490' => ['Letter', [qw/8096/], '3 1/2 inch diskette, non-wrap', 15,
+			            undef, undef, undef, undef, undef, undef,
+			 ],
+			'8160' => ['Letter',[qw/8160/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'8161' => ['Letter',[qw/8161/], 'address', 20,
+					11.2464, 36, 288, 72, 11.2464, 0,
+			],
+			'8162' => ['Letter',[qw/8162/], 'address', 14,
+					11.2536, 63, 285.7536, 101.2536, 13.5, 0,
+			],
+			'8163' => ['Letter',[qw/8163/], 'special', 10,
+					13.5, 36, 288, 144, 9, 0,
+			],
+			'8164' => ['Letter',[qw/8164/], 'shipping', 6,
+					10.656, 36, 288, 239.76, 14.6232, 0,
+			],
+			'8165' => ['Letter',[qw/8165/], 'full sheet', 1,
+					0, 0, 612, 792, 0, 0,
+			],
+			'8167' => ['Letter',[qw/8167 8667/], 'return address', 80,
+					21.3768, 36, 126, 36, 21.7512, 0,
+			],
+			'8196' => ['Letter',[qw/8196/], 'diskette', 9,
+					9, 36, 198, 198, 0, 18,
+			],
+			'8460' => ['Letter',[qw/8460/], 'address', 30,
+					13.5, 36, 189, 72, 9, 0,
+			],
+			'8462' => ['Letter',[qw/8462/], 'address', 14,
+					11.2536, 63, 285.7536, 101.2536, 13.5, 0,
+			],
+			'8463' => ['Letter',[qw/8463/], 'shipping', 10,
+					13.5, 36, 288, 144, 9, 0,
+			],
+	);
+=head1
+old definitions replaced by more complete ones. Overlapping defs are sometimes
+the same, sometimes slightly different. Probably a guage of my ability to
+measure tiny distances.
 	%{$self->{AVERY}} = (
 	         '5267' => ['Letter', [qw/8167 8667/], 'return address', 80,
 			            undef, undef, undef, undef, undef, undef,
@@ -120,6 +289,9 @@ sub initialize {
 	         '5165' => ['Letter', [qw/8165 8255 8665/], 'full sheet', 1,
 			            0, 0, 612, 792, 0, 0,
 			 ],
+	         '5167' => ['Letter', [qw/8167 8257 8667/], 'full sheet', 80,
+			            18, 36, 126, 18, 22.5, 0.36,
+			 ],
 	         '5266' => ['Letter', [qw/8066 8166 8366/], 'file folder', 30,
 			            undef, undef, undef, undef, undef, undef,
 			 ],
@@ -133,7 +305,7 @@ sub initialize {
 			            undef, undef, undef, undef, undef, undef,
 			 ],
 	);
-
+=cut
 }
 
 sub Calibrate {
@@ -1310,6 +1482,8 @@ PostScript::MailLabels::BasicData - Basic data that is used by the MailLabels
 
 =head1 REVISION HISTORY
 
+	Version 1.10 - August 2004
+	Added 5167 Avery stock
 	Version 1.02 - January 2001
 	Fixed calibration axis labels to work for arbitrary paper size
 	Added y_gap to Avery data
